@@ -282,7 +282,7 @@ my $CheckPar =
 					    '-param' => 'yes'),
 				Option->new('-name' => 'keepLastOfWeek',
 					    '-cl_option' => '--keepLastOfWeek',
-					    '-name' => 'keepLastOfWeek',
+					    '-cf_key' => 'keepLastOfWeek',
 					    '-param' => 'yes'),
                                 Option->new('-name' => 'keepDuplicate',
 					    '-cl_option' => '--keepDuplicate',
